//	NPBOptionsDialog.cpp - dialog for selecting sound cards etc.
//	--------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//	--------------------------------------------------------------------------

#include "NPBOptionsDialog.h"
#include "NiallsTB.h"

NPBOptionsDialog::NPBOptionsDialog(Colour col):
DialogWindow(T("Audio Options"), col)
{
	setVisible(true);
}

NPBOptionsDialog::~NPBOptionsDialog()
{

}

//----------------------------------------------------------------------------
NPBOptionsContent::NPBOptionsContent(NPBWindow *parent, Colour col):
Component(),
backColour(col)
{
	int i;

	Parent = parent;

	Strings1 = new StringArray(ASIOAudioIODevice::getASIODeviceNames());

	addAndMakeVisible(Soundcards = new ComboBox(T("Soundcards")));
	Soundcards->addActionListener(this);
	for(i=0;i<Strings1->size();i++)
	{
		Soundcards->addItem((*Strings1)[i], i);
	}
	Soundcards->setSelectedId(0, true);

	addAndMakeVisible(IOs = new SimpleListBox(T("IOs"), this));
	IOs->setOutlineColour(Colours::cadetblue, 1);
    IOs->setRowHeight(20);
    IOs->selectRow(0);
	IOs->setMultipleSelectionEnabled(true);

	for(i=0;i<Soundcards->getNumItems();i++)
	{
		if(Soundcards->getItemText(i) == Parent->getSoundcard())
		{
			Soundcards->setSelectedId(i, false);
			break;
		}
	}
	DeviceChosen();
	for(i=0;i<Strings2.size();i++)
	{
		if(Parent->getInputs()[i])
			IOs->selectRow(i, false, false);
	}
	for(i=0;i<Strings3.size();i++)
	{
		if(Parent->getOutputs()[i])
			IOs->selectRow((i+Strings2.size()), false, false);
	}

	addAndMakeVisible(directMode = new ToggleButton(T("Direct Mode")));
	directMode->setToggleState(Parent->getDirectMode(), false);

	Colour tempc = backColour.darker(0.21f);
	Colour temp2 = backColour.darker(0.61f);
	addAndMakeVisible(OK = new NiallsTB(T("OK"), T("Yay!")));
	OK->setBackgroundColours(tempc, Colours::white);
	OK->addActionListener(this);

	addAndMakeVisible(ControlPanel = new NiallsTB(T("ControlPanel"), T("ASIO settings")));
	ControlPanel->setBackgroundColours(tempc, Colours::white);
	ControlPanel->addActionListener(this);

	addAndMakeVisible(Cancel = new NiallsTB(T("Cancel"), T("Boo!")));
	Cancel->setBackgroundColours(tempc, Colours::white);
	Cancel->addActionListener(this);
}

NPBOptionsContent::~NPBOptionsContent()
{

}

void NPBOptionsContent::paint(Graphics& g)
{
	SolidColourBrush brush(backColour);
	g.setBrush(&brush);
	g.fillAll();
}

void NPBOptionsContent::actionListenerCallback(const String& m)
{
	int i, tempint;
	BitArray InputBits;
	BitArray OutputBits;

	if(m == OK->getName())
	{
		tempint = IOs->getNumSelectedRows();
		for(i=0;i<tempint;i++)
		{
			if(IOs->getSelectedRow(i) < Strings2.size())
			{
				InputBits.setBit(IOs->getSelectedRow(i));
			}
			else
			{
				OutputBits.setBit(IOs->getSelectedRow(i)-Strings2.size());
			}
		}

		if(InputBits.countNumberOfSetBits() != OutputBits.countNumberOfSetBits())
		{
			AlertWindow info(T("Soundcard Error"), T("Please select an equal number of inputs and outputs, preferably two (stereo operation). \n(I know it's a bit of a stupid rule)"), AlertWindow::WarningIcon);
			info.addButton(T("Hmm... OK"), 0);
			info.runModalLoop();
			return;
		}

		Parent->DialogOK(Soundcards->getText(), InputBits, OutputBits);
		Parent->setDirectMode(directMode->getToggleState());
		((DialogWindow *)getParentComponent())->closeButtonPressed();
	}
	else if(m == Cancel->getName())
		((DialogWindow *)getParentComponent())->closeButtonPressed();
	else if(m == ControlPanel->getName())
	{
		NativeDesktopWindow* const w = Parent->getNativeWindow();
		ASIOAudioIODevice tempaudio(Soundcards->getText(), w->getNativeHandle(), true);
		tempaudio.showControlPanel();
	}
	else if(m == Soundcards->getName())
	{
		DeviceChosen();
		IOs->repaint();
	}
}

void NPBOptionsContent::resized()
{
	Soundcards->setBounds(10, 10, (getWidth()-20), 20);
	IOs->setBounds(10, 40, (getWidth()-20), (getHeight()-106));

	directMode->setBounds(10, (getHeight()-61), 100, 25);

	OK->setBounds(10, (getHeight()-31), 100, 25);
	ControlPanel->setBounds((16+getWidth()/3), (getHeight()-31), 100, 25);
	Cancel->setBounds((getWidth()-110), (getHeight()-31), 100, 25);
}

void NPBOptionsContent::paintListBoxItem (int rowNumber,
                           Graphics& g,
                           int width, int height,
                           bool rowIsSelected)
{
	String tempstr;

	if(rowIsSelected)
		g.fillAll (Colours::aquamarine);

	if(rowNumber < Strings2.size())
	{
		tempstr = T("Input - ");
		tempstr += Strings2[rowNumber];
		g.drawText(tempstr, 
				   4, 0, width - 4, height, 
				   Justification::centredLeft, true);
	}
	else
	{
		tempstr = T("Output - ");
		tempstr += Strings3[rowNumber-Strings2.size()];
		g.drawText(tempstr, 
				   4, 0, width - 4, height, 
				   Justification::centredLeft, true);
	}
}

void NPBOptionsContent::DeviceChosen()
{
	NativeDesktopWindow* const w = Parent->getNativeWindow();
	ASIOAudioIODevice tempaudio(Soundcards->getText(), w->getNativeHandle(), true);

	Strings2.clear();
	Strings2 = tempaudio.getInputChannelNames();
	Strings3.clear();
	Strings3 = tempaudio.getOutputChannelNames();

	IOs->updateContent();
}
