//	NPBTutorialDialog.h - Displays a text file in a DialogWindow.
//----------------------------------------------------------------------------
//	This file is part of 'Niall's Pedal Board', a simple ASIO VST host.
//	Copyright (C) 2004-2005  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//----------------------------------------------------------------------------
//	
//	You can e-mail me at niallmoody@yahoo.co.uk if you want.
//	
//----------------------------------------------------------------------------

#ifndef NPBTUTORIALDIALOG_H_
#define NPBTUTORIALDIALOG_H_

#include "StaticImage.h"

///	Displays a text file in a DialogWindow.
/*!
	All the real work is done in NPBTutorialDialogContent.
 */
class NPBTutorialDialog : public DialogWindow
{
  public:
	///	Constructor.
	/*!
		\param col The background colour for the window.
		\param path The path to the text file to display.
	 */
	NPBTutorialDialog(Colour col, String path);
	///	Destructor.
	~NPBTutorialDialog() {};
};

///	Displays a text file in a DialogWindow.
/*!
	Provides some very basic file parsing to allow for images to be displayed
	as well as text.

	To display an image, put the following in a text file:
	\code
	<img=example.png>
	\endcode

	It's not exactly html (html support would be very nice in JUCE though...),
	but it should suffice to create basic help files/tutorials.
 */
class NPBTutorialDialogContent : public Component
{
  public:
	///	Constructor.
	/*!
		\param col The background colour the contents are painted.
		\param path The path to the text file to display.
	 */
	NPBTutorialDialogContent(Colour col, String path);
	///	Destructor.
	~NPBTutorialDialogContent() {};

	///	Colours in the background appropriately.
	void paint(Graphics& g);
  private:
	///	Parses the text file passed in, and creates the appropriate Labels and StaticImages.
	void parseTextFile(String path);

	///	The background colour of the window.
	Colour backColour;
};

///	A Label subclass which does not use fitted text.
/*!
	JUCE v1.12 strips whitespace when it draws fitted text, which messes up
	the formatting of our tutorials.  Hence this subclass...
 */
class DontStripTheWhitespaceLabel : public Label
{
  public:
	DontStripTheWhitespaceLabel(const String &componentName,
								const String &labelText);
  protected:
	void paint(Graphics &g);
};

///	JUCE throws an assert if you feed it relative file paths, so this converts them.
String convertRelativePath(String path);

#endif
